pandastools package
================

Subpackages
-----------

.. toctree::

    pandastools.core
    pandastools.widgets

Module contents
---------------

.. automodule:: pandastools
    :members:
    :undoc-members:
    :show-inheritance:
